rpms/eclipse-cdt/F-12 eclipse-cdt-disable-mylyn.patch, NONE, 1.1 eclipse-cdt-maketargets.patch, NONE, 1.1 .cvsignore, 1.49, 1.50 eclipse-cdt.spec, 1.142, 1.143 sources, 1.59, 1.60

Jeff Johnston jjohnstn at fedoraproject.org
Mon Jun 21 17:57:57 UTC 2010


Author: jjohnstn

Update of /cvs/pkgs/rpms/eclipse-cdt/F-12
In directory cvs01.phx2.fedoraproject.org:/tmp/cvs-serv18765

Modified Files:
	.cvsignore eclipse-cdt.spec sources 
Added Files:
	eclipse-cdt-disable-mylyn.patch eclipse-cdt-maketargets.patch 
Log Message:

* Fri Jun 18 2010 Jeff Johnston  <jjohnstn at redhat.com> 1:6.0.2-1
- Rebase CDT to Galileo SR2 (6.0.2).
- Remove mylyn bridge which is now in mylyn rpm.
- Rebase Autotools/Libhover to Linux tools R0.5.1.
- Remove addbuilder patch which is already part of R0_5_1.
- Remove libhover template patch which is already part of R0_5_1.
- Add libtool as a requirement.
- Fix autotools local patch to add macros directory to build.properties
  of org.eclipse.linuxtools.cdt.autotools.core.
- Add maketargets patch.



eclipse-cdt-disable-mylyn.patch:
 feature.xml |    4 ----
 1 file changed, 4 deletions(-)

--- NEW FILE eclipse-cdt-disable-mylyn.patch ---
--- org.eclipse.cdt.releng/results/features/org.eclipse.cdt.master/feature.xml.orig	2009-06-23 23:07:50.000000000 +0300
+++ org.eclipse.cdt.releng/results/features/org.eclipse.cdt.master/feature.xml	2009-10-28 12:46:20.635310276 +0200
@@ -74,10 +74,6 @@
          version="0.0.0"/>
 
    <includes
-         id="org.eclipse.cdt.mylyn"
-         version="0.0.0"/>
-
-   <includes
          id="org.eclipse.cdt.gnu.dsf"
          version="0.0.0"/>
 

eclipse-cdt-maketargets.patch:
 core/IMakeTargetManager.java         |   27 +++++++++++++++++++++++++--
 core/MakeTargetEvent.java            |   33 ++++++++++++++++++++++++++++-----
 internal/core/MakeTargetManager.java |   25 ++++++++++++++++++++++++-
 internal/core/ProjectTargets.java    |   17 ++++++++++++++++-
 4 files changed, 93 insertions(+), 9 deletions(-)

--- NEW FILE eclipse-cdt-maketargets.patch ---
### Eclipse Workspace Patch 1.0
#P org.eclipse.cdt.make.core
Index: src/org/eclipse/cdt/make/core/MakeTargetEvent.java
===================================================================
RCS file: /cvsroot/tools/org.eclipse.cdt/all/org.eclipse.cdt.make.core/src/org/eclipse/cdt/make/core/MakeTargetEvent.java,v
retrieving revision 1.10
diff -u -r1.10 MakeTargetEvent.java
--- src/org/eclipse/cdt/make/core/MakeTargetEvent.java	11 Feb 2009 19:26:11 -0000	1.10
+++ src/org/eclipse/cdt/make/core/MakeTargetEvent.java	1 Feb 2010 18:59:59 -0000
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2007 QNX Software Systems and others.
+ * Copyright (c) 2000, 2007, 2010 QNX Software Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     QNX Software Systems - Initial API and implementation
+ *     Red Hat Inc. - Allow multiple targets
  *******************************************************************************/
 package org.eclipse.cdt.make.core;
 
@@ -15,7 +16,7 @@
 import org.eclipse.core.resources.IProject;
 
 public class MakeTargetEvent extends EventObject {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 
 	public static final int TARGET_ADD = 1;
 	public static final int TARGET_CHANGED = 2;
@@ -23,7 +24,7 @@
 	public static final int PROJECT_ADDED = 4;
 	public static final int PROJECT_REMOVED = 5;
 
-	IMakeTarget target;
+	IMakeTarget[] targets;
 	IProject project;
 	int type;
 
@@ -33,7 +34,20 @@
 	public MakeTargetEvent(Object source, int type, IMakeTarget target) {
 		super(source);
 		this.type = type;
-		this.target = target;
+		this.targets = new IMakeTarget[] {target};
+	}
+
+	/**
+	 * @param source
+	 * @param type event type (e.g. TARGET_ADD, TARGET_CHANGED)
+	 * @param targets array of MakeTargets
+	 * 
+	 */
+	public MakeTargetEvent(Object source, int type, IMakeTarget[] targets) {
+		super(source);
+		this.type = type;
+		this.targets = new IMakeTarget[targets.length];
+		System.arraycopy(targets, 0, this.targets, 0, targets.length);
 	}
 
 	public MakeTargetEvent(Object source, int type, IProject project) {
@@ -46,7 +60,16 @@
 		return type;
 	}
 
+	/*
+	 * @deprecated
+	 * Use getTargets() instead.
+	 */
+	@Deprecated
 	public IMakeTarget getTarget() {
-		return target;
+		return targets[0];
+	}
+	
+	public IMakeTarget[] getTargets() {
+		return targets;
 	}
 }
Index: src/org/eclipse/cdt/make/internal/core/ProjectTargets.java
===================================================================
RCS file: /cvsroot/tools/org.eclipse.cdt/all/org.eclipse.cdt.make.core/src/org/eclipse/cdt/make/internal/core/ProjectTargets.java,v
retrieving revision 1.30
diff -u -r1.30 ProjectTargets.java
--- src/org/eclipse/cdt/make/internal/core/ProjectTargets.java	18 Mar 2009 17:44:47 -0000	1.30
+++ src/org/eclipse/cdt/make/internal/core/ProjectTargets.java	1 Feb 2010 18:59:59 -0000
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 QNX Software Systems and others.
+ * Copyright (c) 2000, 2008, 2010 QNX Software Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -8,6 +8,7 @@
  * Contributors:
  *     QNX Software Systems - Initial API and implementation
  *     James Blackburn (Broadcom Corp.) - Use ICStorageElement
+ *     Red Hat Inc. - Add set method
  *******************************************************************************/
 package org.eclipse.cdt.make.internal.core;
 
@@ -108,6 +109,20 @@
 		return new IMakeTarget[0];
 	}
 
+	public void set(IContainer container, IMakeTarget[] targets) throws CoreException {
+		List<IMakeTarget> newList = new ArrayList<IMakeTarget>();
+		for (int i = 0; i < targets.length; ++i) {
+			IMakeTarget target = targets[i];
+			target.setContainer(container);
+			if (newList.contains(target)) {
+				throw new CoreException(new Status(IStatus.ERROR, MakeCorePlugin.getUniqueIdentifier(), -1,
+						MakeMessages.getString("MakeTargetManager.target_exists"), null)); //$NON-NLS-1$
+			}
+			newList.add(target);
+		}
+		targetMap.put(container, newList);
+	}
+
 	public IMakeTarget findTarget(IContainer container, String name) {
 		List<IMakeTarget> list = targetMap.get(container);
 		if (list != null) {
Index: src/org/eclipse/cdt/make/internal/core/MakeTargetManager.java
===================================================================
RCS file: /cvsroot/tools/org.eclipse.cdt/all/org.eclipse.cdt.make.core/src/org/eclipse/cdt/make/internal/core/MakeTargetManager.java,v
retrieving revision 1.29
diff -u -r1.29 MakeTargetManager.java
--- src/org/eclipse/cdt/make/internal/core/MakeTargetManager.java	12 Mar 2009 18:21:04 -0000	1.29
+++ src/org/eclipse/cdt/make/internal/core/MakeTargetManager.java	1 Feb 2010 18:59:59 -0000
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2007 QNX Software Systems and others.
+ * Copyright (c) 2000, 2007, 2010 QNX Software Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     QNX Software Systems - Initial API and implementation
+ *     Red Hat Inc. - add setTargets method
  *******************************************************************************/
 package org.eclipse.cdt.make.internal.core;
 
@@ -81,6 +82,28 @@
 		notifyListeners(new MakeTargetEvent(this, MakeTargetEvent.TARGET_ADD, target));
 	}
 
+	public void setTargets(IContainer container, IMakeTarget[] targets) throws CoreException {
+		if (container instanceof IWorkspaceRoot) {
+			throw new CoreException(new Status(IStatus.ERROR, MakeCorePlugin.getUniqueIdentifier(), -1, MakeMessages.getString("MakeTargetManager.add_to_workspace_root"), null)); //$NON-NLS-1$
+		}
+		ProjectTargets projectTargets = projectMap.get(targets[0].getProject());
+		if (projectTargets == null) {
+			projectTargets = readTargets(targets[0].getProject());
+		}
+		if (container == null)
+			container = targets[0].getProject();
+		IMakeTarget[] oldTargets = projectTargets.get(container);
+		projectTargets.set(container, targets);
+		try {
+			writeTargets(projectTargets);
+		} catch (CoreException e) {
+			// we only need to reset the targets if writing of targets fails
+			projectTargets.set(container, oldTargets);
+			throw e;
+		}
+		notifyListeners(new MakeTargetEvent(this, MakeTargetEvent.TARGET_ADD, targets[0]));
+	}
+
 	public boolean targetExists(IMakeTarget target) {
 		ProjectTargets projectTargets = projectMap.get(target.getProject());
 		if (projectTargets == null) {


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/eclipse-cdt/F-12/.cvsignore,v
retrieving revision 1.49
retrieving revision 1.50
diff -u -p -r1.49 -r1.50
--- .cvsignore	11 Dec 2009 22:11:47 -0000	1.49
+++ .cvsignore	21 Jun 2010 17:57:56 -0000	1.50
@@ -41,3 +41,8 @@ ammacros-1.9.5.xml
 ammacros-1.9.6.xml
 eclipse-cdt-fetched-src-autotools-R0_4_0_1.tar.gz
 eclipse-cdt-fetched-src-libhover-R0_4_0.tar.gz
+eclipse-cdt-fetched-src-v201002161416.tar.bz2
+eclipse-cdt-fetched-src-autotools-R0_5_0.tar.gz
+eclipse-cdt-fetched-src-libhover-R0_5_0.tar.gz
+eclipse-cdt-fetched-src-autotools-R0_5_1.tar.gz
+eclipse-cdt-fetched-src-libhover-R0_5_1.tar.gz


Index: eclipse-cdt.spec
===================================================================
RCS file: /cvs/pkgs/rpms/eclipse-cdt/F-12/eclipse-cdt.spec,v
retrieving revision 1.142
retrieving revision 1.143
diff -u -p -r1.142 -r1.143
--- eclipse-cdt.spec	5 Jan 2010 22:49:53 -0000	1.142
+++ eclipse-cdt.spec	21 Jun 2010 17:57:57 -0000	1.143
@@ -7,9 +7,9 @@ Epoch: 1
 %define major                   6
 %define minor                   0       
 %define majmin                  %{major}.%{minor}
-%define micro                   1
+%define micro                   2
 %define eclipse_base            %{_libdir}/eclipse
-%define build_id		200909110608
+%define build_id		201002161416
 
 
 # All arches line up except i386 -> x86
@@ -22,7 +22,7 @@ Epoch: 1
 Summary:        Eclipse C/C++ Development Tools (CDT) plugin
 Name:           eclipse-cdt
 Version:        %{majmin}.%{micro}
-Release:        8%{?dist}
+Release:        1%{?dist}
 License:        EPL and CPL
 Group:          Development/Tools
 URL:            http://www.eclipse.org/cdt
@@ -33,12 +33,14 @@ Requires:       eclipse-platform
 # script.  Note that the optional c99 and upc parsers plus the optional
 # xlc support features have been removed.
 
-Source0: %{name}-fetched-src-CDT_6_0_1.tar.bz2
+Source0: %{name}-fetched-src-v%{build_id}.tar.bz2
 Source4: fetch-cdt.sh
 
-Source1: http://sources.redhat.com/eclipse/autotools/eclipse-cdt-fetched-src-autotools-R0_4_0_1.tar.gz
+Source1: %{name}-fetched-src-autotools-R0_5_1.tar.gz
+Source14: make-autotools-tarball.sh
 
-Source2: http://sources.redhat.com/eclipse/autotools/eclipse-cdt-fetched-src-libhover-R0_4_0.tar.gz
+Source2: %{name}-fetched-src-libhover-R0_5_1.tar.gz
+Source15: make-libhover-tarball.sh
 
 ## The following tarball was generated thusly:
 ##
@@ -102,16 +104,18 @@ Patch16: %{name}-ppc64-add_ldflags.patch
 # https://bugs.eclipse.org/bugs/show_bug.cgi?id=272370
 Patch17: %{name}-ppc64-add_xopen_source-include.patch
 
-# Fix problem in Discovery Tab code that causes NPE for Autotools project
-# https://bugs.eclipse.org/bugs/show_bug.cgi?id=291690
-Patch18: %{name}-discoverytab.patch
-
 # Following is a patch to autotools to supply macro hover docs locally
 # in the plugin.
 Patch19: %{name}-autotools-local.patch
 
+# Disable mylyn bridge compiling. Should be removed when CDT 7.0 is out.
+Patch20: %{name}-disable-mylyn.patch
+
+# Add new setTargets interface to MakeTargetManager for use by Autotools.
+# This can be removed for CDT 7.0.
+Patch21: %{name}-maketargets.patch
+
 BuildRequires: eclipse-pde
-BuildRequires: eclipse-mylyn >= 3.0
 BuildRequires: eclipse-rse >= 3.0
 BuildRequires:  java-devel >= 1.4.2
 BuildRequires: lpg-java-compat
@@ -120,7 +124,7 @@ BuildRequires:  vnc-server
 BuildRequires:  w3m
 %endif
 
-Requires:       gdb make gcc-c++ autoconf automake
+Requires:       gdb make gcc-c++ autoconf automake libtool
 Requires:       eclipse-platform >= 1:3.5.0
 Requires:	eclipse-rse >= 3.0
 
@@ -130,15 +134,6 @@ BuildRoot:     %{_tmppath}/%{name}-%{ver
 %description
 Eclipse features and plugins that are useful for C and C++ development.
 
-%package mylyn
-Summary:        Eclipse C/C++ Development Tools (CDT) SDK plugin
-Group:          Text Editors/Integrated Development Environments (IDE)
-Requires:       %{name} = %{epoch}:%{version}-%{release}
-Requires:       eclipse-mylyn >= 3.0
-
-%description mylyn
-Mylyn integration for CDT.
-
 %package parsers
 Summary:        Eclipse C/C++ Development Tools (CDT) SDK plugin
 Group:          Text Editors/Integrated Development Environments (IDE)
@@ -180,8 +175,8 @@ popd
 pushd results/plugins
 %patch13
 popd
-pushd results/plugins/org.eclipse.cdt.managedbuilder.ui
-%patch18 -p0
+pushd results/plugins/org.eclipse.cdt.make.core
+%patch21 -p0
 popd
 #pushd results/plugins/org.eclipse.cdt.core.tests
 #rm parser/org/eclipse/cdt/core/parser/tests/scanner/LexerTests.java
@@ -221,7 +216,7 @@ mkdir autotools
 pushd autotools
 tar -xzf %{SOURCE1}
 %patch19 -p0
-pushd org.eclipse.linuxtools.cdt.autotools
+pushd org.eclipse.linuxtools.cdt.autotools.core
 mkdir macros
 pushd macros
 cp %{SOURCE8} .
@@ -288,13 +283,17 @@ cd ../org.eclipse.cdt.core.linux
 popd
 %endif
 
+#remove mylyn plugins (part of mylyn srpm now)
+rm -fr results/plugins/org.eclipse.cdt.mylyn*
+%patch20
+
 %build
 export JAVA_HOME=%{java_home}
 export PATH=%{java_bin}:/usr/bin:$PATH
 
 # See comments in the script to understand this.
 /bin/sh -x %{eclipse_base}/buildscripts/copy-platform SDK \
-  %{eclipse_base} mylyn xmlrpc codec httpclient lang rse
+  %{eclipse_base} xmlrpc codec httpclient lang rse
 ln -s %{_javadir}/lpgjavaruntime-1.1.0.jar SDK/plugins/net.sourceforge.lpg.lpgjavaruntime_1.1.0.jar
 SDK=$(cd SDK >/dev/null && pwd)
 
@@ -404,11 +403,9 @@ LAUNCHERJAR=$(ls %{eclipse_base}/plugins
 LAUNCHER=%{eclipse_base}/plugins/$LAUNCHERJAR
 
 installDir=${RPM_BUILD_ROOT}/%{eclipse_base}/dropins/cdt
-mylynInstallDir=${installDir}-mylyn
 parsersInstallDir=${installDir}-parsers
 sdkInstallDir=${installDir}-sdk
 install -d -m755 $installDir
-install -d -m755 $mylynInstallDir
 install -d -m755 $parsersInstallDir
 install -d -m755 $sdkInstallDir
 
@@ -436,10 +433,6 @@ pushd libhover
 unzip -qq -d $installDir build/rpmBuild/org.eclipse.linuxtools.cdt.libhover.zip
 popd
 
-mkdir -p $mylynInstallDir/eclipse/features $mylynInstallDir/eclipse/plugins
-mv $installDir/eclipse/features/*mylyn* $mylynInstallDir/eclipse/features
-mv $installDir/eclipse/plugins/*mylyn* $mylynInstallDir/eclipse/plugins
-
 # Move upc, xlc, and lrparser plugins/features to parsers install area.
 mkdir -p $parsersInstallDir/eclipse/features $parsersInstallDir/eclipse/plugins
 mv $installDir/eclipse/features/*xlc* $parsersInstallDir/eclipse/features
@@ -490,27 +483,6 @@ org.eclipse.equinox.p2.metadata.generato
 rm -rf repo
 popd
 
-# Generate p2 metadata for CDT Mylyn Bridge
-pushd $mylynInstallDir/eclipse
-java -jar $LAUNCHER \
--application \
-org.eclipse.equinox.p2.metadata.generator.EclipseGenerator \
--metadataRepository file:`pwd`/repo \
--artifactRepository file:`pwd`/repo \
--source `pwd` \
--root "CDT Mylyn Bridge" \
--rootVersion %{version} \
--flavor tooling \
--publishArtifacts \
--append \
--artifactRepositoryName "CDT Mylyn" \
--metadataRepositoryName "CDT Mylyn" \
--vmargs \
--Duser.home=$homedir
-
-rm -rf repo
-popd
-
 # Generate p2 metadata for CDT Parsers
 pushd $parsersInstallDir/eclipse
 java -jar $LAUNCHER \
@@ -607,10 +579,6 @@ rm -rf ${RPM_BUILD_ROOT}
 %defattr(-,root,root)
 %{eclipse_base}/dropins/cdt-sdk
 
-%files mylyn
-%defattr(-,root,root)
-%{eclipse_base}/dropins/cdt-mylyn
-
 %files parsers
 %defattr(-,root,root)
 %{eclipse_base}/dropins/cdt-parsers
@@ -622,6 +590,17 @@ rm -rf ${RPM_BUILD_ROOT}
 %endif
 
 %changelog
+* Fri Jun 18 2010 Jeff Johnston  <jjohnstn at redhat.com> 1:6.0.2-1
+- Rebase CDT to Galileo SR2 (6.0.2).
+- Remove mylyn bridge which is now in mylyn rpm.
+- Rebase Autotools/Libhover to Linux tools R0.5.1.
+- Remove addbuilder patch which is already part of R0_5_1.
+- Remove libhover template patch which is already part of R0_5_1.
+- Add libtool as a requirement.
+- Fix autotools local patch to add macros directory to build.properties
+  of org.eclipse.linuxtools.cdt.autotools.core.
+- Add maketargets patch.
+
 * Tue Jan 05 2010 Jeff Johnston  <jjohnstn at redhat.com> 1:6.0.1-8
 - Fix ppc64 prep logic.
 


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/eclipse-cdt/F-12/sources,v
retrieving revision 1.59
retrieving revision 1.60
diff -u -p -r1.59 -r1.60
--- sources	11 Dec 2009 22:11:48 -0000	1.59
+++ sources	21 Jun 2010 17:57:57 -0000	1.60
@@ -2,12 +2,14 @@
 2d4ae0a2131ba1efc896d981072cc091  eclipse-cdt-target_filter.gif.gz
 921f3464c4b5a284473ebdad634e5c2d  libstdc++-v3.libhover
 4bccad3ee92faaca4f8dc3ac6941434e  glibc-2.7-2.libhover
-62e2dcbf8fb1f1b23cc71ae762b873b8  eclipse-cdt-fetched-src-CDT_6_0_1.tar.bz2
 992ad18bb8b4d95e5ecab9138dc379ae  acmacros-2.13.xml
 5bcf3e0c2a780b237bb06226eda7a4e7  acmacros-2.59.xml
 0e096b343447578000c73002dc448afa  acmacros-2.61.xml
 4404043432f7f30300139ce39288ba93  ammacros-1.4-p6.xml
 f6edf5299e6f0d89017bd295a296c2cd  ammacros-1.9.5.xml
 f5c671311f49cdb33eaaa64ab6d781fa  ammacros-1.9.6.xml
-5560963f84030d8a535ce56c7c3c79f5  eclipse-cdt-fetched-src-autotools-R0_4_0_1.tar.gz
-10762b14bfee59132ef50324bb343f71  eclipse-cdt-fetched-src-libhover-R0_4_0.tar.gz
+c42f55b60cdb4410b6c5a5201357e7b8  eclipse-cdt-fetched-src-v201002161416.tar.bz2
+b521cd872ec5776d743a38318a4cbe3e  eclipse-cdt-fetched-src-autotools-R0_5_0.tar.gz
+6a21a7b465d9abce8064186f1ba601c6  eclipse-cdt-fetched-src-libhover-R0_5_0.tar.gz
+dc6dec7fa6a435d7f441b2e4e41f6a4a  eclipse-cdt-fetched-src-autotools-R0_5_1.tar.gz
+b683c120c1c13b56e6992e6b2fc6083c  eclipse-cdt-fetched-src-libhover-R0_5_1.tar.gz



More information about the scm-commits mailing list
Index: src/org/eclipse/cdt/make/core/IMakeTargetManager.java
===================================================================
RCS file: /cvsroot/tools/org.eclipse.cdt/all/org.eclipse.cdt.make.core/src/org/eclipse/cdt/make/core/IMakeTargetManager.java,v
retrieving revision 1.16
diff -u -r1.16 IMakeTargetManager.java
--- src/org/eclipse/cdt/make/core/IMakeTargetManager.java	14 Jun 2007 19:00:48 -0000	1.16
+++ src/org/eclipse/cdt/make/core/IMakeTargetManager.java	1 Feb 2010 18:59:59 -0000
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2007 QNX Software Systems and others.
+ * Copyright (c) 2000, 2007, 2010 QNX Software Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     QNX Software Systems - Initial API and implementation
+ *     Red Hat Inc - Add setTargets method
  *******************************************************************************/
 package org.eclipse.cdt.make.core;
 
@@ -14,6 +15,12 @@
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.runtime.CoreException;
 
+/**
+ * MakeTarget Manager interface.
+ * 
+ * @noimplement This interface is not intended to be implemented by clients.
+ * @noextend This interface is not intended to be extended by clients.
+ */
 public interface IMakeTargetManager {
 	IMakeTarget createTarget(IProject project, String targetName, String targetBuilderID) throws CoreException;
 	/**
@@ -24,7 +31,8 @@
 	void addTarget(IMakeTarget target) throws CoreException;
 	
 	/**
 	 * Adds target to manager on a specific projects folder. 
 	 * @param container
 	 * @param target
 	 * @throws CoreException
@@ -33,6 +41,21 @@
 	void removeTarget(IMakeTarget target) throws CoreException;
 	void renameTarget(IMakeTarget target, String name) throws CoreException;
 	
+	/**
+	 * Set targets on a specific projects folder.  It is assumed
+	 * all targets and container belong to the same project which
+	 * is determined from the first element of the
+	 * targets array.  If no container is specified, the project is used.
+	 * All previous targets for the container are replaced upon success and if
+	 * failure occurs, an exception is thrown and the previous set of targets
+	 * for the container are unchanged.
+	 * 
+	 * @param container to set targets for or null if project should be used
+	 * @param targets array
+	 * @throws CoreException
+	 */
+	public void setTargets(IContainer container, IMakeTarget[] targets) throws CoreException;
+	
 	boolean targetExists(IMakeTarget target);
 	
 	IMakeTarget[] getTargets(IContainer container) throws CoreException;
@@ -24,7 +31,8 @@
 	
 	/**
-	 * Adds target to manager on a specific projects folder. 
+	 * Adds target to manager on a specific projects folder. It is assumed
+	 * that the target and container belong to the same project.
 	 * @param container
 	 * @param target